==> tuia-news-center-api-0.0.65_zr41-20180912.074359-1-sources.jar: cn/com/duiba/tuia/news/center/util/JiGuangPushUtils.java <==
package cn.com.duiba.tuia.news.center.util;

import cn.com.duiba.tuia.news.center.enums.AndroidPushNotificationEnum;
import cn.com.duiba.tuia.news.center.pojo.AndroidPushNotificationPoJo;
import cn.com.duiba.tuia.news.center.pojo.JiGuangPushPoJo;
import cn.jiguang.common.ClientConfig;
import cn.jiguang.common.resp.APIConnectionException;
import cn.jiguang.common.resp.APIRequestException;
import cn.jpush.api.JPushClient;
import cn.jpush.api.device.TagAliasResult;
import cn.jpush.api.push.CIDResult;
import cn.jpush.api.push.model.Message;
import cn.jpush.api.push.model.Platform;
import cn.jpush.api.push.model.PushPayload;
import cn.jpush.api.push.model.audience.Audience;
import cn.jpush.api.push.model.audience.AudienceTarget;
import cn.jpush.api.push.model.notification.AndroidNotification;
import cn.jpush.api.push.model.notification.Notification;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.context.annotation.Configuration;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by zhou_wb on 2018/4/27.
 */
@Configuration
public class JiGuangPushUtils {

    private static String masterSecret;

    private static String appKey;

    private static boolean jiGuangSwitch;

    public static void setMasterSecret(String masterSecret) {
        JiGuangPushUtils.masterSecret = masterSecret;
    }

    public static void setAppKey(String appKey) {
        JiGuangPushUtils.appKey = appKey;
    }

    public static void setJiGuangSwitch(boolean jiGuangSwitch) {
        JiGuangPushUtils.jiGuangSwitch = jiGuangSwitch;
    }

    public static String URL_MAIN_ACTIVITY = "com.ttyouqu.app.module.MainActivity";

    public static String URL_WALLET_ACTIVITY = "com.ttyouqu.app.module.WalletActivity";

    public static String URL_INVITE_ACTIVITY = "com.ttyouqu.app.module.frggame.actinvite.InviteActivity";

    public static String URL_LIMIT_PACKET_ACTIVITY = "com.ttyouqu.app.module.frggame.acttimeredpacket.TimeRedPacketActivity";

    public static String URL_LUCK_PACKET_ACTIVITY = "com.ttyouqu.app.module.actgroupredpacket.GroupRedPacketActivity";



    public static String TODAY_READ_TITLE = "提醒";

    public static String TODAY_READ_ALERT = "今日现金已到账，前往提现>>";

    public static String TODAY_SIGN_TITLE = "【1条未读消息】";

    public static String TODAY_SING_ALERT = "你今日还有现金待领取，看资讯即可轻松赚取，无上限~>>";

    public static String DIS_RED_PACK_TITLE = "现金红包待领取";

    public static String DIS_RED_PACK_ALERT = "今天的现金红包还未领取，时间有限，先领先得>>";

    public static String RECALL_TITLE = "红包到期提醒";

    public static String RECALL_ALERT = "你有一个现金红包即将过期，点击领取>>";

    public static String VERSION_TAG = "VERSION_1.2.3";

    public static String LAND_PACKET_TITLE = "红包收取提醒";

    public static String LAND_PACKET_ALERT = "你的红包已成熟，再不收取就没啦~点击收取>>";


    public static String LIMIT_PACKET_HELP_TITLE = "恭喜";

    public static String LIMIT_PACKET_HELP_ALERT = "有好友帮你拆限时红包啦，快来看看吧>>";

    public static String INVITE_SUCCESS_TITLE = "恭喜";

    public static String INVITE_SUCCESS_ALERT = "有好友绑定了你的邀请码啦，好友阅读后即可拿到现金奖励>>";

    public static String RED_POINT_CONTENT = "redPoint";

    public static String INVITE_CHANGE_REWARD_CONTENT = "inviteChangeReward";

    public static String DOUBLE_PACKET_TITLE = "{{%s}}为你助力成功";

    public static String DOUBLE_PACKET_ALERT = "当前翻倍{{%s}}，快戳进来看看";

    public static String LUCK_PACKET_SEND_IN_TITLE = "恭喜";

    public static String LUCK_PACKET_SEND_IN_ALERT = "有钱入账了，快去看看！";

    public static String LUCK_PACKET_SEND_WAIT_TITLE = "恭喜";

    public static String LUCK_PACKET_SEND_WAIT_ALERT = "你有收益待入账，快去催一下！";


    public static String WAKE_TO_PICK_1_TITLE = "收金币啦！";

    public static String WAKE_TO_PICK_1_ALERT = "您的红包已经成熟，再不收取就要被人偷完啦！点击收取>>";


    public static String WAKE_TO_PICK_2_TITLE = "收红包啦！";

    public static String WAKE_TO_PICK_2_ALERT = "您的红包已成熟，再不收取就要被偷啦！点击收取>>";


    public static String POINT_PACKET_TITLE = "恭喜";

    public static String POINT_PACKET_ALERT = "您获得了新的抽奖机会！快去抽奖！";

    public static String ACTIVITY_REWARD_TITLE = "有新的金币收益啦，快去看看！";
    public static String ACTIVITY_REWARD_ALERT = "有新的金币收益啦，快去看看！";

    public static String ACTIVITY_SET_TITLE = "有金币收益未领取，再不来就晚啦！";
    public static String ACTIVITY_SET_ALERT = "有金币收益未领取，再不来就晚啦！";

    public static void setDeviceTag(JiGuangPushPoJo jiGuangPushPoJo) throws APIConnectionException, APIRequestException {
        JPushClient jpushClient = new JPushClient(masterSecret, appKey, null, ClientConfig.getInstance());
        jpushClient.updateDeviceTagAlias(jiGuangPushPoJo.getRegistrationId(),null,jiGuangPushPoJo.getAddTages(),jiGuangPushPoJo.getRemoveTags());
        jpushClient.close();
    }


    public static PushPayload buildPushObjectWithTag(JiGuangPushPoJo jiGuangPushPoJo, AndroidPushNotificationEnum androidPushNotificationEnum) {


        AndroidNotification androidNotification = AndroidNotification.newBuilder()
                .setUriActivity(androidPushNotificationEnum.getActivityUrl())
                .setAlert(androidPushNotificationEnum.getAlert())
                .setTitle(androidPushNotificationEnum.getTitle())
                .addExtras(androidPushNotificationEnum.getExtra())
                .build();
        Notification notification = Notification.newBuilder().addPlatformNotification(androidNotification).build();


        PushPayload.Builder builder = PushPayload.newBuilder().setPlatform(Platform.all()).setNotification(notification);

        Audience.Builder addAudienceTarget = Audience.newBuilder();

        if (CollectionUtils.isNotEmpty(jiGuangPushPoJo.getAndTags())&&CollectionUtils.isEmpty(jiGuangPushPoJo.getNotTags())){
            addAudienceTarget.addAudienceTarget(AudienceTarget.tag_and(jiGuangPushPoJo.getAndTags()));
        }
        if (CollectionUtils.isEmpty(jiGuangPushPoJo.getAndTags())&&CollectionUtils.isNotEmpty(jiGuangPushPoJo.getNotTags())){
            addAudienceTarget.addAudienceTarget(AudienceTarget.tag_not(jiGuangPushPoJo.getNotTags()));
        }
        if (CollectionUtils.isNotEmpty(jiGuangPushPoJo.getAndTags())&&CollectionUtils.isNotEmpty(jiGuangPushPoJo.getNotTags())){
            addAudienceTarget.addAudienceTarget(AudienceTarget.tag_not(jiGuangPushPoJo.getNotTags()))
                    .addAudienceTarget(AudienceTarget.tag_and(jiGuangPushPoJo.getAndTags()));
        }
        if (!jiGuangSwitch){
            addAudienceTarget.addAudienceTarget(AudienceTarget.registrationId(rids()));
        }
        return builder.setAudience(addAudienceTarget.build())
                .build();

    }

    public static PushPayload buildPushObjectWithRegIds(JiGuangPushPoJo jiGuangPushPoJo, AndroidPushNotificationEnum androidPushNotificationEnum) {
        AndroidNotification androidNotification = AndroidNotification.newBuilder()
                .setUriActivity(androidPushNotificationEnum.getActivityUrl())
                .setAlert(androidPushNotificationEnum.getAlert())
                .setTitle(androidPushNotificationEnum.getTitle())
                .addExtras(androidPushNotificationEnum.getExtra())
                .build();
        Notification notification = Notification.newBuilder()
                .addPlatformNotification(androidNotification).build();
        return PushPayload.newBuilder().setPlatform(Platform.all()).setAudience(Audience.registrationId(jiGuangPushPoJo.getRegistrationIds()))
                    .setNotification(notification).build();
    }

    public static PushPayload buildPushPocketWithRegId(String regId, AndroidPushNotificationEnum androidPushNotificationEnum) {
        AndroidNotification androidNotification = AndroidNotification.newBuilder()
                .setUriActivity(androidPushNotificationEnum.getActivityUrl())
                .setAlert(androidPushNotificationEnum.getAlert())
                .setTitle(androidPushNotificationEnum.getTitle())
                .addExtras(androidPushNotificationEnum.getExtra())
                .build();
        Notification notification = Notification.newBuilder()
                .addPlatformNotification(androidNotification).build();
        return PushPayload.newBuilder().setPlatform(Platform.all()).setAudience(Audience.registrationId(regId))
                .setNotification(notification).build();
    }

    public static PushPayload buildPushPocketWithRegIdForParam(String regId, AndroidPushNotificationPoJo androidPushNotificationPoJo) {
        AndroidNotification androidNotification = AndroidNotification.newBuilder()
                .setUriActivity(androidPushNotificationPoJo.getActivityUrl())
                .setAlert(androidPushNotificationPoJo.getAlert())
                .setTitle(androidPushNotificationPoJo.getTitle())
                .addExtras(androidPushNotificationPoJo.getMap())
                .build();
        Notification notification = Notification.newBuilder()
                .addPlatformNotification(androidNotification).build();
        return PushPayload.newBuilder().setPlatform(Platform.all()).setAudience(Audience.registrationId(regId))
                .setNotification(notification).build();
    }

    public static PushPayload buildRedpointMessageObjectWithRegIds(JiGuangPushPoJo jiGuangPushPoJo){
        Message message = Message.content(RED_POINT_CONTENT);
        return PushPayload.newBuilder().setPlatform(Platform.all()).setAudience(Audience.registrationId(jiGuangPushPoJo.getRegistrationId()))
                .setMessage(message).build();
    }

    public static PushPayload buildChangeRewardMessageObjectWithRegIds(JiGuangPushPoJo jiGuangPushPoJo){
        Message message = Message.content(INVITE_CHANGE_REWARD_CONTENT);
        return PushPayload.newBuilder().setPlatform(Platform.all()).setAudience(Audience.registrationId(jiGuangPushPoJo.getRegistrationId()))
                .setMessage(message).build();
    }

    public static void sendPush(PushPayload pushPayload) throws APIConnectionException, APIRequestException {
        JPushClient jpushClient = new JPushClient(masterSecret, appKey, null, ClientConfig.getInstance());
        jpushClient.sendPush(pushPayload);
        jpushClient.close();
    }

    public static TagAliasResult getTagByRegId(String id) throws APIConnectionException, APIRequestException {
        JPushClient jpushClient = new JPushClient(masterSecret, appKey, null, ClientConfig.getInstance());
        return jpushClient.getDeviceTagAlias(id);
    }

    public static Map<String,String> WALLETPAGEMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","wallet");
        return map;
    }

    public static Map<String,String> MAINPAGEMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","home");
        map.put("tabId","0");
        return map;
    }

    /**
     * 红包农场
     * @return
     */
    public static Map<String,String> REDPACKETFARMMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","home");
        map.put("tabId","1");
        return map;
    }

    public static Map<String,String> INVITEMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","inviteDetail");
        map.put("logFrom","6");
        return map;
    }

    public static Map<String,String> LANDMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","home");
        map.put("tabId","2");
        return map;
    }

    public static Map<String,String> LIMITPACKETMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","timeRedPacket");
        return map;
    }

    public static Map<String,String> LUCKPACKETMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("url","https://activity.tuibat.com/land/landPage?id=MTU5NQ&activityType=groupRedPacket");
        return map;
    }


    public static Map<String,String> POINTPACKETMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("url","https://activity.tuibat.com/land/landPage?id=MTgwNw&activityType=clickTwiceEarn");
        return map;
    }


    public static Map<String,String> POINTPACKETINTRMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("url","https://activity.tuibat.com/land/landPage?id=MTgwNw&activityType=clickTwiceEarn");
        map.put("page","groupRedPacket");
        return map;
    }

    public static Map<String, String> ACTIVITYCOINREWARD() {
        Map<String,String> map = new HashMap<>();
        map.put("url","https://activity.tuibat.com/land/landPage");
        return map;
    }

    public static List<String> getCid(int count) throws APIConnectionException, APIRequestException {
        JPushClient jpushClient = new JPushClient(masterSecret, appKey, null, ClientConfig.getInstance());
        CIDResult cidResult = jpushClient.getCidList(count, null);
        return cidResult.cidlist;
    }

    private static List<String> rids(){
        List<String> list = new ArrayList<>();
        if (!jiGuangSwitch){
            list.add("18071adc03074a33fa5");
            list.add("1507bfd3f7eae7fb926");
            list.add("18071adc03074ad1eda");
            list.add("160a3797c80f8ecdf54");
            list.add("1507bfd3f7ea24e1a2c");
            list.add("18071adc03077642880");
            list.add("170976fa8aad91a0877");
            list.add("1507bfd3f79564a0231");
            list.add("18071adc035e3f252f7");
        }
        return list;
    }



}

==> tuia-news-center-api-0.0.67-zr8-20180926.051135-2-sources.jar: cn/com/duiba/tuia/news/center/util/JiGuangPushUtils.java <==
package cn.com.duiba.tuia.news.center.util;

import cn.com.duiba.tuia.news.center.enums.AndroidPushNotificationEnum;
import cn.com.duiba.tuia.news.center.pojo.AndroidPushNotificationPoJo;
import cn.com.duiba.tuia.news.center.pojo.JiGuangPushPoJo;
import cn.jiguang.common.ClientConfig;
import cn.jiguang.common.resp.APIConnectionException;
import cn.jiguang.common.resp.APIRequestException;
import cn.jpush.api.JPushClient;
import cn.jpush.api.device.TagAliasResult;
import cn.jpush.api.push.CIDResult;
import cn.jpush.api.push.model.Message;
import cn.jpush.api.push.model.Platform;
import cn.jpush.api.push.model.PushPayload;
import cn.jpush.api.push.model.audience.Audience;
import cn.jpush.api.push.model.audience.AudienceTarget;
import cn.jpush.api.push.model.notification.AndroidNotification;
import cn.jpush.api.push.model.notification.Notification;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.context.annotation.Configuration;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by zhou_wb on 2018/4/27.
 */
@Configuration
public class JiGuangPushUtils {

    private static String masterSecret;

    private static String appKey;

    private static boolean jiGuangSwitch;

    public static void setMasterSecret(String masterSecret) {
        JiGuangPushUtils.masterSecret = masterSecret;
    }

    public static void setAppKey(String appKey) {
        JiGuangPushUtils.appKey = appKey;
    }

    public static void setJiGuangSwitch(boolean jiGuangSwitch) {
        JiGuangPushUtils.jiGuangSwitch = jiGuangSwitch;
    }

    public static String URL_MAIN_ACTIVITY = "com.ttyouqu.app.module.MainActivity";

    public static String URL_WALLET_ACTIVITY = "com.ttyouqu.app.module.WalletActivity";

    public static String URL_INVITE_ACTIVITY = "com.ttyouqu.app.module.frggame.actinvite.InviteActivity";

    public static String URL_LIMIT_PACKET_ACTIVITY = "com.ttyouqu.app.module.frggame.acttimeredpacket.TimeRedPacketActivity";

    public static String URL_LUCK_PACKET_ACTIVITY = "com.ttyouqu.app.module.actgroupredpacket.GroupRedPacketActivity";



    public static String TODAY_READ_TITLE = "提醒";

    public static String TODAY_READ_ALERT = "今日现金已到账，前往提现>>";

    public static String TODAY_SIGN_TITLE = "【1条未读消息】";

    public static String TODAY_SING_ALERT = "你今日还有现金待领取，看资讯即可轻松赚取，无上限~>>";

    public static String DIS_RED_PACK_TITLE = "现金红包待领取";

    public static String DIS_RED_PACK_ALERT = "今天的现金红包还未领取，时间有限，先领先得>>";

    public static String RECALL_TITLE = "红包到期提醒";

    public static String RECALL_ALERT = "你有一个现金红包即将过期，点击领取>>";

    public static String VERSION_TAG = "VERSION_1.2.3";

    public static String LAND_PACKET_TITLE = "红包收取提醒";

    public static String LAND_PACKET_ALERT = "你的红包已成熟，再不收取就没啦~点击收取>>";


    public static String LIMIT_PACKET_HELP_TITLE = "恭喜";

    public static String LIMIT_PACKET_HELP_ALERT = "有好友帮你拆限时红包啦，快来看看吧>>";

    public static String INVITE_SUCCESS_TITLE = "恭喜";

    public static String INVITE_SUCCESS_ALERT = "有好友绑定了你的邀请码啦，好友阅读后即可拿到现金奖励>>";

    public static String RED_POINT_CONTENT = "redPoint";

    public static String INVITE_CHANGE_REWARD_CONTENT = "inviteChangeReward";

    public static String DOUBLE_PACKET_TITLE = "{{%s}}为你助力成功";

    public static String DOUBLE_PACKET_ALERT = "当前翻倍{{%s}}，快戳进来看看";

    public static String LUCK_PACKET_SEND_IN_TITLE = "恭喜";

    public static String LUCK_PACKET_SEND_IN_ALERT = "有钱入账了，快去看看！";

    public static String LUCK_PACKET_SEND_WAIT_TITLE = "恭喜";

    public static String LUCK_PACKET_SEND_WAIT_ALERT = "你有收益待入账，快去催一下！";


    public static String WAKE_TO_PICK_1_TITLE = "收金币啦！";

    public static String WAKE_TO_PICK_1_ALERT = "您的红包已经成熟，再不收取就要被人偷完啦！点击收取>>";


    public static String WAKE_TO_PICK_2_TITLE = "收红包啦！";

    public static String WAKE_TO_PICK_2_ALERT = "您的红包已成熟，再不收取就要被偷啦！点击收取>>";


    public static String POINT_PACKET_TITLE = "恭喜";

    public static String POINT_PACKET_ALERT = "您获得了新的抽奖机会！快去抽奖！";

    public static String ACTIVITY_REWARD_TITLE = "有新的金币收益啦，快去看看！";
    public static String ACTIVITY_REWARD_ALERT = "有新的金币收益啦，快去看看！";

    public static String ACTIVITY_SET_TITLE = "有金币收益未领取，再不来就晚啦！";
    public static String ACTIVITY_SET_ALERT = "有金币收益未领取，再不来就晚啦！";

    public static void setDeviceTag(JiGuangPushPoJo jiGuangPushPoJo) throws APIConnectionException, APIRequestException {
        JPushClient jpushClient = new JPushClient(masterSecret, appKey, null, ClientConfig.getInstance());
        jpushClient.updateDeviceTagAlias(jiGuangPushPoJo.getRegistrationId(),null,jiGuangPushPoJo.getAddTages(),jiGuangPushPoJo.getRemoveTags());
        jpushClient.close();
    }


    public static PushPayload buildPushObjectWithTag(JiGuangPushPoJo jiGuangPushPoJo, AndroidPushNotificationEnum androidPushNotificationEnum) {


        AndroidNotification androidNotification = AndroidNotification.newBuilder()
                .setUriActivity(androidPushNotificationEnum.getActivityUrl())
                .setAlert(androidPushNotificationEnum.getAlert())
                .setTitle(androidPushNotificationEnum.getTitle())
                .addExtras(androidPushNotificationEnum.getExtra())
                .build();
        Notification notification = Notification.newBuilder().addPlatformNotification(androidNotification).build();


        PushPayload.Builder builder = PushPayload.newBuilder().setPlatform(Platform.all()).setNotification(notification);

        Audience.Builder addAudienceTarget = Audience.newBuilder();

        if (CollectionUtils.isNotEmpty(jiGuangPushPoJo.getAndTags())&&CollectionUtils.isEmpty(jiGuangPushPoJo.getNotTags())){
            addAudienceTarget.addAudienceTarget(AudienceTarget.tag_and(jiGuangPushPoJo.getAndTags()));
        }
        if (CollectionUtils.isEmpty(jiGuangPushPoJo.getAndTags())&&CollectionUtils.isNotEmpty(jiGuangPushPoJo.getNotTags())){
            addAudienceTarget.addAudienceTarget(AudienceTarget.tag_not(jiGuangPushPoJo.getNotTags()));
        }
        if (CollectionUtils.isNotEmpty(jiGuangPushPoJo.getAndTags())&&CollectionUtils.isNotEmpty(jiGuangPushPoJo.getNotTags())){
            addAudienceTarget.addAudienceTarget(AudienceTarget.tag_not(jiGuangPushPoJo.getNotTags()))
                    .addAudienceTarget(AudienceTarget.tag_and(jiGuangPushPoJo.getAndTags()));
        }
        if (!jiGuangSwitch){
            addAudienceTarget.addAudienceTarget(AudienceTarget.registrationId(rids()));
        }
        return builder.setAudience(addAudienceTarget.build())
                .build();

    }

    public static PushPayload buildPushObjectWithRegIds(JiGuangPushPoJo jiGuangPushPoJo, AndroidPushNotificationEnum androidPushNotificationEnum) {
        AndroidNotification androidNotification = AndroidNotification.newBuilder()
                .setUriActivity(androidPushNotificationEnum.getActivityUrl())
                .setAlert(androidPushNotificationEnum.getAlert())
                .setTitle(androidPushNotificationEnum.getTitle())
                .addExtras(androidPushNotificationEnum.getExtra())
                .build();
        Notification notification = Notification.newBuilder()
                .addPlatformNotification(androidNotification).build();
        return PushPayload.newBuilder().setPlatform(Platform.all()).setAudience(Audience.registrationId(jiGuangPushPoJo.getRegistrationIds()))
                    .setNotification(notification).build();
    }

    public static PushPayload buildPushPocketWithRegId(String regId, AndroidPushNotificationEnum androidPushNotificationEnum) {
        AndroidNotification androidNotification = AndroidNotification.newBuilder()
                .setUriActivity(androidPushNotificationEnum.getActivityUrl())
                .setAlert(androidPushNotificationEnum.getAlert())
                .setTitle(androidPushNotificationEnum.getTitle())
                .addExtras(androidPushNotificationEnum.getExtra())
                .build();
        Notification notification = Notification.newBuilder()
                .addPlatformNotification(androidNotification).build();
        return PushPayload.newBuilder().setPlatform(Platform.all()).setAudience(Audience.registrationId(regId))
                .setNotification(notification).build();
    }

    public static PushPayload buildPushPocketWithRegIdForParam(String regId, AndroidPushNotificationPoJo androidPushNotificationPoJo) {
        AndroidNotification androidNotification = AndroidNotification.newBuilder()
                .setUriActivity(androidPushNotificationPoJo.getActivityUrl())
                .setAlert(androidPushNotificationPoJo.getAlert())
                .setTitle(androidPushNotificationPoJo.getTitle())
                .addExtras(androidPushNotificationPoJo.getMap())
                .build();
        Notification notification = Notification.newBuilder()
                .addPlatformNotification(androidNotification).build();
        return PushPayload.newBuilder().setPlatform(Platform.all()).setAudience(Audience.registrationId(regId))
                .setNotification(notification).build();
    }

    public static PushPayload buildRedpointMessageObjectWithRegIds(JiGuangPushPoJo jiGuangPushPoJo){
        Message message = Message.content(RED_POINT_CONTENT);
        return PushPayload.newBuilder().setPlatform(Platform.all()).setAudience(Audience.registrationId(jiGuangPushPoJo.getRegistrationId()))
                .setMessage(message).build();
    }

    public static PushPayload buildChangeRewardMessageObjectWithRegIds(JiGuangPushPoJo jiGuangPushPoJo){
        Message message = Message.content(INVITE_CHANGE_REWARD_CONTENT);
        return PushPayload.newBuilder().setPlatform(Platform.all()).setAudience(Audience.registrationId(jiGuangPushPoJo.getRegistrationId()))
                .setMessage(message).build();
    }

    public static void sendPush(PushPayload pushPayload) throws APIConnectionException, APIRequestException {
        JPushClient jpushClient = new JPushClient(masterSecret, appKey, null, ClientConfig.getInstance());
        jpushClient.sendPush(pushPayload);
        jpushClient.close();
    }

    public static TagAliasResult getTagByRegId(String id) throws APIConnectionException, APIRequestException {
        JPushClient jpushClient = new JPushClient(masterSecret, appKey, null, ClientConfig.getInstance());
        return jpushClient.getDeviceTagAlias(id);
    }

    public static Map<String,String> WALLETPAGEMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","wallet");
        return map;
    }

    public static Map<String,String> MAINPAGEMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","home");
        map.put("tabId","0");
        return map;
    }

    /**
     * 红包农场
     * @return
     */
    public static Map<String,String> REDPACKETFARMMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","home");
        map.put("tabId","1");
        return map;
    }

    public static Map<String,String> INVITEMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","inviteDetail");
        map.put("logFrom","6");
        return map;
    }

    public static Map<String,String> LANDMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","home");
        map.put("tabId","2");
        return map;
    }

    public static Map<String,String> LIMITPACKETMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("page","timeRedPacket");
        return map;
    }

    public static Map<String,String> LUCKPACKETMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("url","https://activity.tuibat.com/land/landPage?id=MTU5NQ&activityType=groupRedPacket");
        return map;
    }


    public static Map<String,String> POINTPACKETMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("url","https://activity.tuibat.com/land/landPage?id=MTgwNw&activityType=clickTwiceEarn");
        return map;
    }


    public static Map<String,String> POINTPACKETINTRMAP(){
        Map<String,String> map = new HashMap<>();
        map.put("url","https://activity.tuibat.com/land/landPage?id=MTgwNw&activityType=clickTwiceEarn");
        map.put("page","groupRedPacket");
        return map;
    }

    public static Map<String, String> ACTIVITYCOINREWARD() {
        Map<String,String> map = new HashMap<>();
        map.put("url","https://api.tuipine.com/landPage/index/NA==");
        map.put("page","groupRedPacket");
        return map;
    }

    public static List<String> getCid(int count) throws APIConnectionException, APIRequestException {
        JPushClient jpushClient = new JPushClient(masterSecret, appKey, null, ClientConfig.getInstance());
        CIDResult cidResult = jpushClient.getCidList(count, null);
        return cidResult.cidlist;
    }

    private static List<String> rids(){
        List<String> list = new ArrayList<>();
        if (!jiGuangSwitch){
            list.add("18071adc03074a33fa5");
            list.add("1507bfd3f7eae7fb926");
            list.add("18071adc03074ad1eda");
            list.add("160a3797c80f8ecdf54");
            list.add("1507bfd3f7ea24e1a2c");
            list.add("18071adc03077642880");
            list.add("170976fa8aad91a0877");
            list.add("1507bfd3f79564a0231");
            list.add("18071adc035e3f252f7");
        }
        return list;
    }



}
